@@ -24,7 +24,7 @@ _srcfile = os.path.normcase(currentframe.__code__.co_filename)
 
 class BaseLog:
 
-    log_levels = ['info', 'debug', 'warn', 'error']
+    log_levels = ['info', 'debug', 'warn', 'error', 'trace']
 
     def __init__(self, app_name, prefix_path,  t_code, f_code="", when="D", backup_count=3,
                  journal_log_enable=True):
@@ -51,6 +51,8 @@ class BaseLog:
             handler_dict[level]['level'] = level.upper()
             if level == 'info':
                 file_name = self.journal_log_name
+            elif level == 'trace':
+                file_name = self.job_log_name
             else:
                 file_name = self.program_log_name
             handler_dict[level]['filename'] = os.path.join(self.prefix_path, '%s-%s.%s.log' % (file_name, level, pid))
@@ -60,8 +62,10 @@ class BaseLog:
         loggers_dict = dict()
         loggers_dict[self.program_log_name] = dict()
         loggers_dict[self.journal_log_name] = dict()
+        loggers_dict[self.job_log_name] = dict()
         loggers_dict[self.program_log_name]['handlers'] = ['debug', 'warn', 'error']
         loggers_dict[self.journal_log_name]['handlers'] = ['info']
+        loggers_dict[self.job_log_name]['handlers'] = ['trace']
         for logger in loggers_dict.keys():
             loggers_dict[logger]['level'] = 'DEBUG'
             loggers_dict[logger]['propagate'] = False
